@@ -1,21 +1,18 @@
 import collections
 
 from django.db.models import signals
-from django.core.signals import request_finished
 from pyelasticsearch import ElasticSearch
 
-from .settings import ES_USE_REQUEST_FINISHED_SIGNAL, ES_BULK_LIMIT_BEFORE_SEND
+from .settings import ES_USE_REQUEST_FINISHED_SIGNAL, ES_BULK_LIMIT_BEFORE_SEND, ES_CONNECTION_URL
 
 
 if ES_USE_REQUEST_FINISHED_SIGNAL:
+    from django.core.signals import request_finished
     ES_REQUEST_FINISHED_DATA = collections.defaultdict(lambda: [])
 
     def process_bulk_data(sender, **kwargs):
         global ES_REQUEST_FINISHED_DATA
 
-        # TODO: come up with way to batch ALL different index bulk data into 
-        # a single set of data to maximize bulk calls
-        
         # ask each ES index instance to handle its own 'sending' to ES
         for index, data in ES_REQUEST_FINISHED_DATA.iteritems():
             index.bulk_send(data)
@@ -26,31 +23,6 @@ if ES_USE_REQUEST_FINISHED_SIGNAL:
     request_finished.connect(process_bulk_data, dispatch_uid=u'ES_USE_REQUEST_FINISHED_SIGNAL')
 
 
-class ESDirectMixin:
-    """ Use this mixin to enable auto-indexing/deleting through Django model
-    save/delete signal handlers.
-    """
-    use_signals = True
-
-
-class ESRabbitMQMixin:
-    """ Use this mixin to enable auto-indexing/deleting through Django model
-    save/delete signal handlers. Instead of communicating with ES directly, this
-    mixin sends all single/bulk requests through RabbitMQ using the ES 'river'
-    configuration.
-    """
-    use_signals = True
-
-    def index_object(self, obj):
-        pass
-
-    def delete_object(self, obj):
-        pass
-
-    def bulk_send(self, data):
-        pass
-
-
 class ESBaseIndex(object):
     use_signals = False
     _es = None
@@ -66,7 +38,7 @@ class ESBaseIndex(object):
     @property
     def es(self):
         if not self._es:
-            self._es = ElasticSearch('http://localhost:9200/')
+            self._es = ElasticSearch(ES_CONNECTION_URL)
         return self._es
 
     def register_signals(self):
@@ -98,7 +70,7 @@ class ESBaseIndex(object):
         self.perform_action(instance, 'delete')
 
     def perform_action(self, obj, operation, bulk=ES_USE_REQUEST_FINISHED_SIGNAL):
-        if obj and obj.pk:
+        if obj and self.get_object_id(obj):
             if operation == 'index' and self.should_index(obj):
                 if bulk:
                     self.bulk_queue(obj, operation)
@@ -128,7 +100,7 @@ class ESBaseIndex(object):
         data = {
             '_index': self._index_name,
             '_type': self._type_name,
-            "_id": obj.pk
+            "_id": self.get_object_id(obj)
         }
         data.update(self.get_object_params(obj))
 
@@ -158,7 +130,7 @@ class ESBaseIndex(object):
             self._index_name,
             self._type_name,
             self.get_object_data(obj),
-            id=obj.pk,
+            id=self.get_object_id(obj),
             **self.get_object_params(obj)
         )
 
@@ -166,7 +138,7 @@ class ESBaseIndex(object):
         self.es.delete(
             self._index_name,
             self._type_name,
-            id=obj.pk,
+            id=self.get_object_id(obj),
             **self.get_object_params(obj)
         )
 
@@ -193,6 +165,9 @@ class ESBaseIndex(object):
         # get routing, ttl, timestamp, etc. options for the item
         return {}
 
+    def get_object_id(self, obj):
+        return obj.pk
+
     def get_object_data(self, obj):
         # This must return a dictionary
         raise NotImplementedError
@@ -201,31 +176,20 @@ class ESBaseIndex(object):
         raise NotImplementedError
 
 
+class ESDirectMixin:
+    """ Use this mixin to enable auto-indexing/deleting through Django model
+    save/delete signal handlers.
+    """
+    use_signals = True
 
 
-# if amqp:
-#     # TODO: rewrite the self.es.* calls below to send data to the rabbitmq river instead
-#     class ESMessageQueueDriverMixin(ESBaseDriverMixin):
-#         """ This mixin uses the concept of ES's Redis or RabbitMQ 'rivers' to send
-#         bulk-index/delete formatted data to ES via Redis or RabbitMQ.
-#         """
-
-### instead of the below, perhaps use Kombu as we'll be able to create a redis driver too
-
+# TODO: Consider implementing Elasticsearch 'river' mixins; example below
+# class ESRabbitMQMixin:
+#     """ Use this mixin to enable auto-indexing/deleting through Django model
+#     save/delete signal handlers. Instead of communicating with ES directly, this
+#     mixin sends all single/bulk requests through RabbitMQ using the ES 'river'
+#     configuration.
+#     """
+#     use_signals = True
 #
-#                 # conn = amqp.Connection(options.host, userid=options.userid,
-#                 #                        password=options.password, ssl=options.ssl)
-#                 #
-#                 # ch = conn.channel()
-#                 # ch.exchange_declare('myfan', 'fanout')
-#                 #
-#                 # msg = amqp.Message(msg_body, content_type='text/plain',
-#                 #                    application_headers={'foo': 7, 'bar': 'baz'})
-#                 #
-#                 # ch.basic_publish(msg, 'myfan')
-#                 #
-#                 # ch.close()
-#                 # conn.close()
-#
-
-
+#     # ... other implementation overrides here ...
